song-cli

A command Line interface to download hindi and punjabi songs from internet

-----------------------------------------------------
Example:
song -d tum ho
song -d ik kudi
song -d mai ho na

It will download the file in current working directory
----------------------------------------------------
For Installing
pip install song

----------------------------------------------------
For Uninstalling 
pip uninstall song

